@@ -161,6 +161,9 @@ function insert_brand($frm) {
 	global $SESSION;
 	include ($CFG->global);
 
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	INSERT INTO brands (name, description)
 	VALUES ('$frm[name]', '$frm[description]')
@@ -177,6 +180,9 @@ function update_brand($id, $frm) {
 	global $SESSION;
 	include ($CFG->global);
 
+	while (list($key, $val) = each($frm)){
+		if (is_string($val)) $frm[$key] = addslashes($val);
+	}
 	$qid = db_query("
 	UPDATE brands SET
 		name = '$frm[name]'
@@ -248,6 +254,8 @@ function import_brands($userfile) {
 	$fcontents = file ($userfile);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
+		// Microsoft Stupidity Suppression
+		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 
