@@ -176,7 +176,7 @@ function print_iva_list() {
 
 	if (!isset($page_number) || $dbchanged) {
 		$qid = db_query("
-		SELECT id, iva FROM iva WHERE id > 1 ORDER BY iva");
+		SELECT id, iva FROM iva WHERE id > 0 ORDER BY iva");
 
 		$SESSION["numr"] = db_num_rows($qid);
 		for ($i=0; $i<$SESSION["numr"]; $i++) {
@@ -225,6 +225,8 @@ function import_iva($userfile) {
 	$fcontents = file ($userfile);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
+		// Microsoft Stupidity Suppression
+		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 
