@@ -240,7 +240,8 @@ function get_cart_items() {
 		return false;
 	}
 
-	return db_query ("SELECT * FROM products WHERE id IN ($in_clause)"); }
+	return db_query ("SELECT * FROM products WHERE id IN ($in_clause)");
+}
 
 //function chop_ccnum($ccnum) {
 ///* this function returns the the first and last 4 digits of the credit card number
@@ -656,6 +657,7 @@ function validate_phone($phone, &$errors, &$msg) {
 	} else {
 		$phone = ereg_replace (" ", "", $phone);
 		$phone = ereg_replace ("\+", "", $phone);
+		$phone = ereg_replace ("\-", "", $phone);
 		$phone = ereg_replace ("\(", "", $phone);
 		$phone = ereg_replace ("\)", "", $phone);
 		$phone = ereg_replace ("\/", "", $phone);
