@@ -275,7 +275,7 @@ $I_agree_with_the_usage_of_the_presently_given_data = "Autorizzo il trattamento
 $I_accept_to_receive_advertising_matherial = "Accetto di ricevere materiale pubblicitario";
 $I_agree_with_the_usage_of_my_personal_data = "Autorizzo il trattamento dei miei dati personali";
 $appoggio = return_star();
-$Please_fill_out_this_contact_form = "Sei pregato di riempire il seguente modulo; tieni presente che &egrave; obbligatorio riempire tutti i campi contrassegnati con un asterisco (" . $appoggio . ").";
+$Please_fill_out_this_contact_form = "Sei pregato di riempire il seguente modulo; tieni presente che &egrave; necessario riempire tutti i campi contrassegnati con un asterisco (" . $appoggio . ").";
 $First_and_Last_Name = "Nome e Cognome<br>(o Ragione Sociale)";
 $Message = "Messaggio";
 $Send = "Spedisci";
