@@ -275,7 +275,7 @@ $I_agree_with_the_usage_of_the_presently_given_data = "I agree with the usage of
 $I_accept_to_receive_advertising_matherial = "I accept to receive advertising matherial";
 $I_agree_with_the_usage_of_my_personal_data = "I agree with the usage of my personal data";
 $appoggio = return_star();
-$Please_fill_out_this_contact_form = "Please fill out this contact form, note that all fields labeled through an asterisk (" . $appoggio . ") are mandatory.";
+$Please_fill_out_this_contact_form = "Please fill out this contact form; note that all fields labeled with an asterisk (" . $appoggio . ") are required.";
 $First_and_Last_Name = "First and Last Name<br>(or Enterprise Name)";
 $Message = "Message";
 $Send = "Send";
